StackTraceParser class

Constructors

StackTraceParser(StackTrace trace)

Properties

fileName ↔ String
getter/setter pair
function ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineNumber ↔ String
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trace → StackTrace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited