LoggerParameters class
Constructors
-
LoggerParameters({int maxLength = 54, String dateFormat = "HH:mm:ss:SSS", bool showLog = true, bool showInitMessage = true, List<
LoggerTypeState> filterTypes = const [], List<String> filterTags = const []}) -
const
Properties
- dateFormat → String
-
final
-
filterTags
→ List<
String> -
final
-
filterTypes
→ List<
LoggerTypeState> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInitMessage → bool
-
final
- showLog → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited